@@ -51,17 +51,14 @@
 #define RATIO_RANDOM_SEARCH 0.2
 
 #ifndef _REENTRANT
-#undef HAVE_PTHREAD_H
+#  undef HAVE_PTHREAD_H
 #endif
 
 #ifndef ENABLE_DEBUG_VERBOSITY
-#define ARMA_DONT_PRINT_RUNTIME_ERRORS 1
-#define ARMA_DONT_PRINT_ERRORS 1
-#undef ARMA_PRINT_ERRORS
-#define ARMA_NO_DEBUG 1
+#  define ARMA_DONT_PRINT_RUNTIME_ERRORS 1
+#  define ARMA_DONT_PRINT_ERRORS 1
+#  undef  ARMA_PRINT_ERRORS
+#  define ARMA_NO_DEBUG 1
 #endif
 
-#define ARMA_DONT_USE_CXX11 1
-#define ARMA_DONT_USE_WRAPPER 1
-
 #endif
